@@ -15,6 +15,7 @@ from cvxpy.interface.matrix_utilities import scalar_value
 from cvxpy.problems.problem import SizeMetrics, SolverStats
 
 from cvxpy_leximin.objective import Leximax, Leximin
+from copy import deepcopy
 
 LOGGER = logging.getLogger("__cvxpy_leximin__")
 
@@ -109,6 +110,7 @@ class Problem(cvxpy.problems.problem.Problem):
             return scalar_value(self._value)
 
     def _solve_sub_problem(self, sub_problem: cvxpy.Problem, *args, **kwargs):
+        kwargs = deepcopy(kwargs)  # cvxpy.Problem.solve might modify kwargs.
         sub_problem.solve(*args, **kwargs)
         if sub_problem.status == "infeasible":
             self._status = sub_problem.status
@@ -124,6 +126,13 @@ class Problem(cvxpy.problems.problem.Problem):
     def _solve_leximin(self, *args, **kwargs):
         """
         Find a leximin-optimal vector of utilities, subject to the given constraints.
+
+        The algorithm is based on:
+        > [Stephen J. Willson](https://faculty.sites.iastate.edu/swillson/),
+        > "Fair Division Using Linear Programming" (1998).
+        > Part 6, pages 20--27.
+
+        I am grateful to Sylvain Bouveret for his help with the algorithm. All remaining errors and bugs are my own.
         """
         if type(self.objective) == Leximax:
             sub_objectives = [-arg for arg in self.objective.args]
